function [ret,x0,str,ts,xts]=lagr_sim(t,x,u,flag);
%LAGR_SIM	is the M-file description of the SIMULINK system named LAGR_SIM.
%	The block-diagram can be displayed by typing: LAGR_SIM.
%
%	SYS=LAGR_SIM(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes LAGR_SIM to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling LAGR_SIM with a FLAG of zero:
%	[SIZES]=LAGR_SIM([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[375,102,1020,376])
     open_system(sys)
end;
set_param(sys,'BackGround',0)
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '100')
set_param(sys,'Min step size', '0.05')
set_param(sys,'Max step size', '0.06')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn3'])
set_param([sys,'/','MATLAB Fcn3'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','out_x_y(u)',...
		'Output Width','2',...
		'position',[295,126,375,164])


%     Subsystem  'UnNamed2'.

new_system([sys,'/','UnNamed2'])
set_param([sys,'/','UnNamed2'],'Location',[528,478,1014,783])

add_block('built-in/Integrator',[sys,'/','UnNamed2/Integrator'])
set_param([sys,'/','UnNamed2/Integrator'],...
		'Initial','etat_init',...
		'position',[310,75,345,105])

add_block('built-in/State-Space',[sys,'/','UnNamed2/Matrice des inerties '])
set_param([sys,'/','UnNamed2/Matrice des inerties '],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','K',...
		'Mask Display','K',...
		'Mask Type','Matrix gain',...
		'Mask Dialogue','Matrix Gain.|Gain matrix:')
set_param([sys,'/','UnNamed2/Matrice des inerties '],...
		'Mask Translate','K = @1;',...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).')
set_param([sys,'/','UnNamed2/Matrice des inerties '],...
		'Mask Entries','[1/Ir 0 0;0 1/It 0;0 0 1/Il;0 0 0;0 0 0;0 0 0;0 0 0 ]\/',...
		'position',[100,48,155,82])

add_block('built-in/Inport',[sys,'/','UnNamed2/Couple'])
set_param([sys,'/','UnNamed2/Couple'],...
		'position',[25,55,45,75])

add_block('built-in/Outport',[sys,'/','UnNamed2/out_1'])
set_param([sys,'/','UnNamed2/out_1'],...
		'position',[415,80,435,100])

add_block('built-in/Mux',[sys,'/','UnNamed2/Mux'])
set_param([sys,'/','UnNamed2/Mux'],...
		'orientation',2,...
		'inputs','[7 3]',...
		'position',[180,134,210,276])

add_block('built-in/Sum',[sys,'/','UnNamed2/Sum'])
set_param([sys,'/','UnNamed2/Sum'],...
		'position',[260,44,275,131])

add_block('built-in/Constant',[sys,'/','UnNamed2/I'])
set_param([sys,'/','UnNamed2/I'],...
		'orientation',2,...
		'Value','[Ir It Il]',...
		'position',[240,227,320,253])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed2/der_sys.m'])
set_param([sys,'/','UnNamed2/der_sys.m'],...
		'orientation',2,...
		'MATLAB Fcn','lagrange(u)',...
		'Output Width','7',...
		'position',[80,185,145,225])

add_block('built-in/Note',[sys,'/','UnNamed2/Inerties'])
set_param([sys,'/','UnNamed2/Inerties'],...
		'position',[280,250,285,255])
add_line([sys,'/','UnNamed2'],[50,65;95,65])
add_line([sys,'/','UnNamed2'],[280,90;305,90])
add_line([sys,'/','UnNamed2'],[350,90;410,90])
add_line([sys,'/','UnNamed2'],[360,90;360,170;215,170])
add_line([sys,'/','UnNamed2'],[235,240;215,240])
add_line([sys,'/','UnNamed2'],[175,205;150,205])
add_line([sys,'/','UnNamed2'],[75,205;70,205;70,110;255,110])
add_line([sys,'/','UnNamed2'],[160,65;255,65])
set_param([sys,'/','UnNamed2'],...
		'Mask Display','DYNAMIQUE\n\nSATELLITE\n\nQUATERNIONS')


%     Finished composite block 'UnNamed2'.

set_param([sys,'/','UnNamed2'],...
		'ForeGround',1,...
		'BackGround',6,...
		'hide name',0,...
		'position',[85,109,215,181])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','x_y',...
		'position',[455,137,505,153])


%     Subsystem  'XY Graph'.

new_system([sys,'/','XY Graph'])
set_param([sys,'/','XY Graph'],'Location',[8,52,282,245])

add_block('built-in/Inport',[sys,'/','XY Graph/y'])
set_param([sys,'/','XY Graph/y'],...
		'Port','2',...
		'position',[10,100,30,120])

add_block('built-in/Inport',[sys,'/','XY Graph/x'])
set_param([sys,'/','XY Graph/x'],...
		'position',[10,30,30,50])

add_block('built-in/Mux',[sys,'/','XY Graph/Mux'])
set_param([sys,'/','XY Graph/Mux'],...
		'inputs','2',...
		'position',[100,61,130,94])

add_block('built-in/S-Function',[sys,'/',['XY Graph/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['XY Graph/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunxy',...
		'parameters','ax, st',...
		'position',[185,70,235,90])
add_line([sys,'/','XY Graph'],[35,110;70,110;70,85;95,85])
add_line([sys,'/','XY Graph'],[35,40;70,40;70,70;95,70])
add_line([sys,'/','XY Graph'],[135,80;180,80])
set_param([sys,'/','XY Graph'],...
		'Mask Display','plot(0,0,100,100,[12,91,91,12,12],[90,90,45,45,90],[51,57,65,75,80,79,75,67,60,54,51,48,42,34,28,27,31,42,51],[71,68,66,66,72,79,83,84,81,77,71,60,54,54,58,65,71,74,71])')
set_param([sys,'/','XY Graph'],...
		'Mask Type','XY scope.',...
		'Mask Dialogue','XY scope using MATLAB graph window.\nFirst input is used as time base.\nEnter plotting ranges.|x-min:|x-max:|y-min:|y-max:')
set_param([sys,'/','XY Graph'],...
		'Mask Translate','ax = [@1, @2, @3, @4];st=-1;',...
		'Mask Help','This block can be used to explore limit cycles. Look at the m-file sfunxy.m to see how it works.')
set_param([sys,'/','XY Graph'],...
		'Mask Entries','-wmax\/wmax\/-wmax\/wmax\/')


%     Finished composite block 'XY Graph'.

set_param([sys,'/','XY Graph'],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[580,71,610,109])

add_block('built-in/Demux',[sys,'/','Demux'])
set_param([sys,'/','Demux'],...
		'ForeGround',2,...
		'hide name',0,...
		'outputs','2',...
		'position',[465,68,510,112])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn2'])
set_param([sys,'/','MATLAB Fcn2'],...
		'orientation',2,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','cple_pes(u)',...
		'Output Width','3',...
		'position',[85,202,190,238])

add_block('built-in/Note',[sys,'/',['SORTIE DE LA TRAJECTOIRE',13,'DE L''EXTREMITE DE L''AXE  ',13,'z SUR LE PLAN XOY']])
set_param([sys,'/',['SORTIE DE LA TRAJECTOIRE',13,'DE L''EXTREMITE DE L''AXE  ',13,'z SUR LE PLAN XOY']],...
		'ForeGround',3,...
		'Font Size',12,...
		'position',[525,155,530,160])

add_block('built-in/Note',[sys,'/',['Initialisation en lanant poin_dat.m',13,'dans l''espace Matlab ']])
set_param([sys,'/',['Initialisation en lanant poin_dat.m',13,'dans l''espace Matlab ']],...
		'ForeGround',5,...
		'position',[465,215,470,220])

add_block('built-in/Note',[sys,'/',['QUATERNIONS:',13,'ETUDE DU MOUVEMENT DE LAGRANGE ET POISSON']])
set_param([sys,'/',['QUATERNIONS:',13,'ETUDE DU MOUVEMENT DE LAGRANGE ET POISSON']],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[315,5,320,10])

add_block('built-in/Note',[sys,'/','Couple'])
set_param([sys,'/','Couple'],...
		'position',[145,240,150,245])

add_block('built-in/Note',[sys,'/','Sign: GUIZIOU 2005'])
set_param([sys,'/','Sign: GUIZIOU 2005'],...
		'position',[310,240,315,245])
add_line(sys,[220,145;290,145])
add_line(sys,[80,220;40,220;40,145;80,145])
add_line(sys,[265,145;265,220;195,220])
add_line(sys,[380,145;450,145])
add_line(sys,[515,80;575,80])
add_line(sys,[515,100;575,100])
add_line(sys,[395,145;395,90;460,90])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
